summaryrefslogtreecommitdiff
path: root/backend/pdf/ev-poppler.cc
diff options
context:
space:
mode:
Diffstat (limited to 'backend/pdf/ev-poppler.cc')
-rw-r--r--backend/pdf/ev-poppler.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/backend/pdf/ev-poppler.cc b/backend/pdf/ev-poppler.cc
index e2abb55d..8049db55 100644
--- a/backend/pdf/ev-poppler.cc
+++ b/backend/pdf/ev-poppler.cc
@@ -1,5 +1,5 @@
/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; c-indent-level: 8 -*- */
/* this file is part of evince, a mate document viewer
*
* Copyright (C) 2009, Juanjo MarĂ­n <[email protected]>
* Copyright (C) 2004, Red Hat, Inc.
@@ -1074,7 +1074,7 @@ ev_link_dest_from_dest (PdfDocument *pdf_document,
if (unimplemented_dest) {
g_warning ("Unimplemented destination: %s, please post a "
- "bug report in Evince bugzilla "
+ "bug report in Atril bugzilla "
"(http://bugzilla.mate.org) with a testcase.",
unimplemented_dest);
}
@@ -1139,7 +1139,7 @@ ev_link_from_action (PdfDocument *pdf_document,
if (unimplemented_action) {
g_warning ("Unimplemented action: %s, please post a bug report "
- "in Evince bugzilla (http://bugzilla.mate.org) "
+ "in Atril bugzilla (http://bugzilla.mate.org) "
"with a testcase.", unimplemented_action);
}
@@ -2694,7 +2694,7 @@ ev_annot_from_poppler_annot (PopplerAnnot *poppler_annot,
if (unimplemented_annot) {
g_warning ("Unimplemented annotation: %s, please post a "
- "bug report in Evince bugzilla "
+ "bug report in Atril bugzilla "
"(http://bugzilla.mate.org) with a testcase.",
unimplemented_annot);
}
@@ -1,5 +1,5 @@
/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; c-indent-level: 8 -*- */
-/* this file is part of evince, a mate document viewer
+/* this file is part of atril, a mate document viewer
*
* Copyright (C) 2009, Juanjo MarĂ­n <[email protected]>